.designer-icon-combo {
    background-image:url(../images/combo-field.png) !important;
}
.designer-icon-fieldset {
    background-image:url(../images/fieldset.png) !important;
}
.designer-icon-number {
    background-image:url(../images/number-field.png) !important;
}
.designer-icon-text {
    background-image:url(../images/text-field.png) !important;
}
.designer-icon-page {
    background-image:url(../images/page.png) !important;
}
.designer-icon-datefield {
    background-image:url(../images/date-field.png) !important;
}